@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11999 2020-03-24 13:31:45Z Andy $
+# $Id: models.py 12014 2020-03-25 11:57:46Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2020-03-24 22:31:45 +0900 (週二, 24 三月 2020) $
-# $Revision: 11999 $
+# $Date: 2020-03-25 19:57:46 +0800 (週三, 25 三月 2020) $
+# $Revision: 12014 $
 
 import hashlib
 
@@ -37,7 +37,7 @@ class URL(models.Model):
     
     def save(self, *args, **kwargs):
         if self.url:
-            self.checksum = hashlib.md5(self.url.encode("utf-8"))
+            self.checksum = hashlib.md5(self.url.encode("utf-8")).hexdigest()
         super().save(*args, **kwargs)
 
     class Meta:
